==> kstreamripper-0.7.1.tar.bz2: kstreamripper/scripts/extract-messages.sh <==
#!/bin/sh
# Extracts the messages which have to be translated, puts them in a .pot file
# and merges this .pot file with the existing translations.
# based on code from
# http://techbase.kde.org/Development/Tutorials/Localization/i18n_Build_Systems
SCRIPTDIR=`pwd`


BASEDIR="${SCRIPTDIR}/../src/"          # root of translatable sources
TIPOFTHEDAYDIR="${SCRIPTDIR}/../data/"  # directory with the tips of the day
DESKTOPFILEDIR="${SCRIPTDIR}/../data/"  # directory with the desktop files
RPMSPECDIR="${SCRIPTDIR}/../templates/" # directory with the desktop files
PROJECT="kstreamripper"                 # project name
BUGADDR="http://sourceforge.net/projects/kstreamripper/"      # MSGID-Bugs
WDIR="${SCRIPTDIR}/../po"               # working dir
 
 
export PATH=/usr/bin:$PATH
 
 
echo "Preparing rc files"
cd ${BASEDIR}
# we use simple sorting to make sure the lines do not jump around too much from system to system
find . -name '*.rc' -o -name '*.ui' -o -name '*.kcfg' | sort > ${WDIR}/rcfiles.list
export PATH=/usr/bin:$PATH # We want to use the KDE 4 version of extractrc!
xargs --arg-file=${WDIR}/rcfiles.list extractrc > ${WDIR}/rc.cpp
cd ${TIPOFTHEDAYDIR}
preparetips >> ${WDIR}/rc.cpp
cd ${DESKTOPFILEDIR}
${SCRIPTDIR}/messageextract-desktopfile.sh kstreamripper.desktop >> ${WDIR}/rc.cpp
cd ${RPMSPECDIR}
${SCRIPTDIR}/messageextract-rpmspec.sh template.spec >> ${WDIR}/rc.cpp
cd ${WDIR}
echo "Done preparing rc files"
 
 
echo "Extracting messages"
cd ${BASEDIR}
# see above on sorting
find . -name '*.cpp' -o -name '*.h' -o -name '*.c' | sort > ${WDIR}/infiles.list
echo "./rc.cpp" >> ${WDIR}/infiles.list
cd ${WDIR}
xgettext --from-code=UTF-8 -C -kde -ci18n -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1 \
        -kI18N_NOOP:1 -kI18N_NOOP2:1c,2 -kaliasLocale -kki18n:1 -kki18nc:1c,2 -kki18np:1,2 -kki18ncp:1c,2,3 \
   --msgid-bugs-address="${BUGADDR}" \
     --files-from=infiles.list -D ${BASEDIR} -D ${WDIR} -o ${PROJECT}.pot || { echo "error while calling xgettext. aborting."; exit 1; }
echo "Done extracting messages"
 
 
echo "Build languagetool"
cd ${WDIR}/languagetool-build
cmake ../languagetool
make
echo "Done build languagetool"
 
 
echo "Merging translations"
cd ${WDIR}
catalogs=`find . -maxdepth 1 -name '*.po'`
for cat in $catalogs; do
  # produce a file that preserves the translation of changed strings
  msgmerge --no-fuzzy-matching --previous --quiet -o $cat.new1 $cat ${PROJECT}.pot
  # produce a file with fuzzy merging (does not preserve the original of the fuzzy changes)
  msgmerge --quiet -o $cat.new2 $cat ${PROJECT}.pot
  # merge the "fuzzy file" with the "preserve file"
  # So we get both: fuzzy merging AND preserving _each_ yet translated string!
  msgmerge --no-fuzzy-matching --previous --quiet -o $cat.new3 $cat.new2 $cat.new1
  rm $cat.new1
  rm $cat.new2
  mv $cat.new3 $cat
  cat $cat \
   | languagetool-build/languagetool dump-translation \
   | languagetool-build/languagetool simplify-control-sequences \
   > $cat.txt
done
echo "Done merging translations"
 
 
echo "Merging english translation review"
cd ${WDIR}/review
# remove fuzzy messages that could have been introduced by the reviewer
# (applies also for messages that are commented out)
msgattrib --no-fuzzy kstreamripper_en_US.po > kstreamripper_en_US.po.new
mv kstreamripper_en_US.po.new kstreamripper_en_US.po
cd ${WDIR}
# merge (the removed fuzzy messages should now be reintroduced, but without translation)
msgmerge --no-fuzzy-matching --previous --quiet -o review/kstreamripper_en_US.po.new review/kstreamripper_en_US.po ${PROJECT}.pot
cd ${WDIR}/review
mv kstreamripper_en_US.po.new kstreamripper_en_US.po
# keep up to date the "list of pending changes"
cat kstreamripper_en_US.po | ../languagetool-build/languagetool dump-difference > pending-changes.po
echo "Done merging english translation review"
 
 
echo "Cleaning up"
cd ${WDIR}
rm rcfiles.list
rm infiles.list
rm rc.cpp
echo "Done cleaning up"

==> kstreamripper-0.7.100.tar.bz2: kstreamripper/scripts/extract-messages.sh <==
#!/bin/sh
# Extracts the messages which have to be translated, puts them in a .pot file
# and merges this .pot file with the existing translations.
# based on code from
# http://techbase.kde.org/Development/Tutorials/Localization/i18n_Build_Systems
SCRIPTDIR=`pwd`


BASEDIR="${SCRIPTDIR}/../src/"          # root of translatable sources
TIPOFTHEDAYDIR="${SCRIPTDIR}/../data/"  # directory with the tips of the day
DESKTOPFILEDIR="${SCRIPTDIR}/../data/"  # directory with the desktop files
RPMSPECDIR="${SCRIPTDIR}/../templates/" # directory with the desktop files
PROJECT="kstreamripper"                 # project name
BUGADDR="http://sourceforge.net/projects/kstreamripper/"      # MSGID-Bugs
WDIR="${SCRIPTDIR}/../po"               # working dir
 
 
export PATH=/usr/bin:$PATH
 
 
echo "Preparing rc files"
cd ${BASEDIR}
# we use simple sorting to make sure the lines do not jump around too much from system to system
find . -name '*.rc' -o -name '*.ui' -o -name '*.kcfg' | grep --invert-match  ^\./thirdparty/agateau-columnresizer-9ae599c/demo/ | sort > ${WDIR}/rcfiles.list
export PATH=/usr/bin:$PATH # We want to use the KDE 4 version of extractrc!
xargs --arg-file=${WDIR}/rcfiles.list extractrc > ${WDIR}/rc.cpp
cd ${TIPOFTHEDAYDIR}
preparetips >> ${WDIR}/rc.cpp
cd ${DESKTOPFILEDIR}
intltool-extract --quiet --type=gettext/ini ../templates/kstreamripper.desktop
cat ../templates/kstreamripper.desktop.h >> ${WDIR}/rc.cpp
rm ../templates/kstreamripper.desktop.h
cd ${RPMSPECDIR}
${SCRIPTDIR}/messageextract-rpmspec.sh template.spec >> ${WDIR}/rc.cpp
cd ${WDIR}
echo "Done preparing rc files"
 
 
echo "Extracting messages"
cd ${BASEDIR}
# see above on sorting
find . -name '*.cpp' -o -name '*.h' -o -name '*.c' | grep --invert-match  ^\./thirdparty/agateau-columnresizer-9ae599c/demo/ | sort > ${WDIR}/infiles.list
echo "./rc.cpp" >> ${WDIR}/infiles.list
cd ${WDIR}
xgettext --from-code=UTF-8 -C -kde -ci18n -kN_:1 -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1 \
        -kI18N_NOOP:1 -kI18N_NOOP2:1c,2 -kaliasLocale -kki18n:1 -kki18nc:1c,2 -kki18np:1,2 -kki18ncp:1c,2,3 \
   --msgid-bugs-address="${BUGADDR}" \
     --files-from=infiles.list -D ${BASEDIR} -D ${WDIR} -o ${PROJECT}.pot || { echo "error while calling xgettext. aborting."; exit 1; }
echo "Done extracting messages"
 
 
echo "Merging translations"
cd ${WDIR}
catalogs=`find . -maxdepth 1 -name '*.po'`
for cat in $catalogs; do
  # produce a file that preserves the translation of changed strings
  msgmerge --no-fuzzy-matching --previous --quiet -o $cat.new1 $cat ${PROJECT}.pot
  # produce a file with fuzzy merging (does not preserve the original of the fuzzy changes)
  msgmerge --quiet -o $cat.new2 $cat ${PROJECT}.pot
  # merge the "fuzzy file" with the "preserve file"
  # So we get both: fuzzy merging AND preserving _each_ yet translated string!
  msgmerge --no-fuzzy-matching --previous --quiet -o $cat.new3 $cat.new2 $cat.new1
  rm $cat.new1
  rm $cat.new2
  mv $cat.new3 $cat
  cat $cat \
   | poreviewtool dump-translation \
   > $cat.txt
done
cd ${WDIR}
intltool-merge --quiet --desktop-style ${WDIR} ${SCRIPTDIR}/../templates/kstreamripper.desktop ${DESKTOPFILEDIR}/kstreamripper.desktop
echo "Done merging translations"
 
 
echo "Merging english translation review"
poreviewtool msgmerge ${WDIR}/review/kstreamripper_en_US.po ${WDIR}/${PROJECT}.pot
# keep up to date the "list of pending changes"
cd ${WDIR}/review
cat kstreamripper_en_US.po | poreviewtool dump-difference > pending-changes.po
echo "Done merging english translation review"
 
 
echo "Cleaning up"
cd ${WDIR}
rm rcfiles.list
rm infiles.list
rm rc.cpp
echo "Done cleaning up"
